@@ -6,14 +6,15 @@ module Bio.FASTA
   , fromFile
   , toFile
   , fastaP
-  , fastaPGeneric
   , fastaLine
   , modificationP
+  , Parser
   ) where
 
 import Control.Monad.IO.Class (MonadIO, liftIO)
-import Data.Attoparsec.Text   (parseOnly)
 import Data.Text.IO           (readFile, writeFile)
+import System.FilePath        (takeBaseName)
+import Text.Megaparsec        (errorBundlePretty, parse)
 #if !MIN_VERSION_base(4,13,0)
 import Control.Monad.Fail (MonadFail (..))
 import Prelude            hiding (fail, readFile, writeFile)
@@ -28,7 +29,7 @@ import Bio.FASTA.Writer (WritableFastaToken (..), fastaToText)
 -- | Reads 'FastaSequence' from given file.
 --
 fromFile :: (MonadFail m, MonadIO m) => FilePath -> m (Fasta Char)
-fromFile f = liftIO (readFile f) >>= either fail pure . parseOnly fastaP
+fromFile f = liftIO (readFile f) >>= either (fail . errorBundlePretty) pure . parse fastaP (takeBaseName f)
 
 -- | Writes 'FastaSequence' to file.
 --
